@@ -6,6 +6,12 @@ function(x,
 	cat(x$method)
 	cat("\t\tLink:\t")
 	cat(x$link)
+	if (x$method == "formula") {
+		cat("\n\nformula:\t")
+		cat(deparse(x$formula))
+		cat("\n\nparameters:\t")
+		cat(format(x$par, digits = digits))
+		}
 	cat("\n\nPerceptual Scale:\n")
 	print.default(format(x$pscale, digits = digits), 
 		quote = FALSE, ...)
